@@ -28,27 +28,27 @@ from .literals import (
 )
 from .paginator import ListProfileTimesPaginator
 from .type_defs import (
-    AddNotificationChannelsResponseResponseTypeDef,
+    AddNotificationChannelsResponseTypeDef,
     AgentOrchestrationConfigTypeDef,
-    BatchGetFrameMetricDataResponseResponseTypeDef,
+    BatchGetFrameMetricDataResponseTypeDef,
     ChannelTypeDef,
-    ConfigureAgentResponseResponseTypeDef,
-    CreateProfilingGroupResponseResponseTypeDef,
-    DescribeProfilingGroupResponseResponseTypeDef,
+    ConfigureAgentResponseTypeDef,
+    CreateProfilingGroupResponseTypeDef,
+    DescribeProfilingGroupResponseTypeDef,
     FrameMetricTypeDef,
-    GetFindingsReportAccountSummaryResponseResponseTypeDef,
-    GetNotificationConfigurationResponseResponseTypeDef,
-    GetPolicyResponseResponseTypeDef,
-    GetProfileResponseResponseTypeDef,
-    GetRecommendationsResponseResponseTypeDef,
-    ListFindingsReportsResponseResponseTypeDef,
-    ListProfileTimesResponseResponseTypeDef,
-    ListProfilingGroupsResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
-    PutPermissionResponseResponseTypeDef,
-    RemoveNotificationChannelResponseResponseTypeDef,
-    RemovePermissionResponseResponseTypeDef,
-    UpdateProfilingGroupResponseResponseTypeDef,
+    GetFindingsReportAccountSummaryResponseTypeDef,
+    GetNotificationConfigurationResponseTypeDef,
+    GetPolicyResponseTypeDef,
+    GetProfileResponseTypeDef,
+    GetRecommendationsResponseTypeDef,
+    ListFindingsReportsResponseTypeDef,
+    ListProfileTimesResponseTypeDef,
+    ListProfilingGroupsResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
+    PutPermissionResponseTypeDef,
+    RemoveNotificationChannelResponseTypeDef,
+    RemovePermissionResponseTypeDef,
+    UpdateProfilingGroupResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -80,7 +80,7 @@ class Exceptions:
 
 class CodeGuruProfilerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html)
     """
 
@@ -89,11 +89,11 @@ class CodeGuruProfilerClient:
 
     def add_notification_channels(
         self, *, channels: List["ChannelTypeDef"], profilingGroupName: str
-    ) -> AddNotificationChannelsResponseResponseTypeDef:
+    ) -> AddNotificationChannelsResponseTypeDef:
         """
         Add up to 2 anomaly notifications channels for a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.add_notification_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.add_notification_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#add_notification_channels)
         """
 
@@ -106,12 +106,12 @@ class CodeGuruProfilerClient:
         period: str = None,
         startTime: Union[datetime, str] = None,
         targetResolution: AggregationPeriodType = None
-    ) -> BatchGetFrameMetricDataResponseResponseTypeDef:
+    ) -> BatchGetFrameMetricDataResponseTypeDef:
         """
         Returns the time series of values for a requested list of frame metrics from a
         time period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.batch_get_frame_metric_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.batch_get_frame_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#batch_get_frame_metric_data)
         """
 
@@ -119,7 +119,7 @@ class CodeGuruProfilerClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#can_paginate)
         """
 
@@ -129,11 +129,11 @@ class CodeGuruProfilerClient:
         profilingGroupName: str,
         fleetInstanceId: str = None,
         metadata: Dict[MetadataFieldType, str] = None
-    ) -> ConfigureAgentResponseResponseTypeDef:
+    ) -> ConfigureAgentResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#configure_agent)
         """
 
@@ -145,11 +145,11 @@ class CodeGuruProfilerClient:
         agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef" = None,
         computePlatform: ComputePlatformType = None,
         tags: Dict[str, str] = None
-    ) -> CreateProfilingGroupResponseResponseTypeDef:
+    ) -> CreateProfilingGroupResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#create_profiling_group)
         """
 
@@ -157,17 +157,17 @@ class CodeGuruProfilerClient:
         """
         Deletes a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#delete_profiling_group)
         """
 
     def describe_profiling_group(
         self, *, profilingGroupName: str
-    ) -> DescribeProfilingGroupResponseResponseTypeDef:
+    ) -> DescribeProfilingGroupResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#describe_profiling_group)
         """
 
@@ -181,35 +181,35 @@ class CodeGuruProfilerClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#generate_presigned_url)
         """
 
     def get_findings_report_account_summary(
         self, *, dailyReportsOnly: bool = None, maxResults: int = None, nextToken: str = None
-    ) -> GetFindingsReportAccountSummaryResponseResponseTypeDef:
+    ) -> GetFindingsReportAccountSummaryResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_findings_report_account_summary)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_findings_report_account_summary)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_findings_report_account_summary)
         """
 
     def get_notification_configuration(
         self, *, profilingGroupName: str
-    ) -> GetNotificationConfigurationResponseResponseTypeDef:
+    ) -> GetNotificationConfigurationResponseTypeDef:
         """
         Get the current configuration for anomaly notifications for a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_notification_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_notification_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_notification_configuration)
         """
 
-    def get_policy(self, *, profilingGroupName: str) -> GetPolicyResponseResponseTypeDef:
+    def get_policy(self, *, profilingGroupName: str) -> GetPolicyResponseTypeDef:
         """
         Returns the JSON-formatted resource-based policy on a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_policy)
         """
 
@@ -222,11 +222,11 @@ class CodeGuruProfilerClient:
         maxDepth: int = None,
         period: str = None,
         startTime: Union[datetime, str] = None
-    ) -> GetProfileResponseResponseTypeDef:
+    ) -> GetProfileResponseTypeDef:
         """
         Gets the aggregated profile of a profiling group for a specified time range.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_profile)
         """
 
@@ -237,11 +237,11 @@ class CodeGuruProfilerClient:
         profilingGroupName: str,
         startTime: Union[datetime, str],
         locale: str = None
-    ) -> GetRecommendationsResponseResponseTypeDef:
+    ) -> GetRecommendationsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_recommendations)
         """
 
@@ -254,11 +254,11 @@ class CodeGuruProfilerClient:
         dailyReportsOnly: bool = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListFindingsReportsResponseResponseTypeDef:
+    ) -> ListFindingsReportsResponseTypeDef:
         """
         List the available reports for a given profiling group and time range.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_findings_reports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_findings_reports)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_findings_reports)
         """
 
@@ -272,32 +272,30 @@ class CodeGuruProfilerClient:
         maxResults: int = None,
         nextToken: str = None,
         orderBy: OrderByType = None
-    ) -> ListProfileTimesResponseResponseTypeDef:
+    ) -> ListProfileTimesResponseTypeDef:
         """
         Lists the start times of the available aggregated profiles of a profiling group
         for an aggregation period within the specified time range.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_profile_times)
         """
 
     def list_profiling_groups(
         self, *, includeDescription: bool = None, maxResults: int = None, nextToken: str = None
-    ) -> ListProfilingGroupsResponseResponseTypeDef:
+    ) -> ListProfilingGroupsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_profiling_groups)
         """
 
-    def list_tags_for_resource(
-        self, *, resourceArn: str
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Returns a list of the tags that are assigned to a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_tags_for_resource)
         """
 
@@ -312,7 +310,7 @@ class CodeGuruProfilerClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#post_agent_profile)
         """
 
@@ -323,32 +321,32 @@ class CodeGuruProfilerClient:
         principals: List[str],
         profilingGroupName: str,
         revisionId: str = None
-    ) -> PutPermissionResponseResponseTypeDef:
+    ) -> PutPermissionResponseTypeDef:
         """
         Adds permissions to a profiling group's resource-based policy that are provided
         using an action group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#put_permission)
         """
 
     def remove_notification_channel(
         self, *, channelId: str, profilingGroupName: str
-    ) -> RemoveNotificationChannelResponseResponseTypeDef:
+    ) -> RemoveNotificationChannelResponseTypeDef:
         """
         Remove one anomaly notifications channel for a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_notification_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_notification_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#remove_notification_channel)
         """
 
     def remove_permission(
         self, *, actionGroup: Literal["agentPermissions"], profilingGroupName: str, revisionId: str
-    ) -> RemovePermissionResponseResponseTypeDef:
+    ) -> RemovePermissionResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#remove_permission)
         """
 
@@ -363,7 +361,7 @@ class CodeGuruProfilerClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.submit_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.submit_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#submit_feedback)
         """
 
@@ -371,7 +369,7 @@ class CodeGuruProfilerClient:
         """
         Use to assign one or more tags to a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#tag_resource)
         """
 
@@ -379,7 +377,7 @@ class CodeGuruProfilerClient:
         """
         Use to remove one or more tags from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#untag_resource)
         """
 
@@ -388,11 +386,11 @@ class CodeGuruProfilerClient:
         *,
         agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef",
         profilingGroupName: str
-    ) -> UpdateProfilingGroupResponseResponseTypeDef:
+    ) -> UpdateProfilingGroupResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#update_profiling_group)
         """
 
@@ -400,6 +398,6 @@ class CodeGuruProfilerClient:
         self, operation_name: Literal["list_profile_times"]
     ) -> ListProfileTimesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
         """
