@@ -24,14 +24,14 @@ from typing import Iterator, Union
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import AggregationPeriodType, OrderByType
-from .type_defs import ListProfileTimesResponseResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import ListProfileTimesResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListProfileTimesPaginator",)
 
 
 class ListProfileTimesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
     """
 
@@ -44,8 +44,8 @@ class ListProfileTimesPaginator(Boto3Paginator):
         startTime: Union[datetime, str],
         orderBy: OrderByType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListProfileTimesResponseResponseTypeDef]:
+    ) -> Iterator[ListProfileTimesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
         """
